@@ -12,15 +12,22 @@ class ProcessorService(processor_pb2_grpc.ProcessorServicer):
     def Execute(self, request, context):
         # get the string from the incoming request
         flow_name = request.flowName
-        data = request.data
+        content = request.content
+        attributes = request.attributes
 
         try:
-            data = json.loads(data)
+            content = json.loads(content)
         except:
             pass
-        for item in self.flow_manager.run(flow_name, data):
+        try:
+            attributes = json.loads(attributes)
+        except:
+            pass
+        for item in self.flow_manager.run(flow_name, content, attributes):
             yield processor_pb2.FlowResponse(
-                data=json.dumps(item, default=grebble_converter), streamEnd=False
+                attributes=json.dumps(item.attributes, default=grebble_converter),
+                content=json.dumps(item.content, default=grebble_converter),
+                streamEnd=False,
             )
 
-        yield processor_pb2.FlowResponse(data=None, streamEnd=True)
+        yield processor_pb2.FlowResponse(data=None, attributes=None, streamEnd=True)
