@@ -1,3 +1,5 @@
+from dataclasses_serialization.json import JSONSerializer
+
 from grebble_flow.managment.processor import find_all_processors
 
 
@@ -14,6 +16,11 @@ class FlowManager:
 
         return result[0]()
 
-    def run(self, flow_name, data):
+    def run(self, flow_name, content, attributes_req):
         flow_processor = self.find_processor_instance_by_name(flow_name)
-        return flow_processor.execute(data=data)
+        attributes = None
+        if flow_processor.attributes:
+            attributes = JSONSerializer.deserialize(
+                flow_processor.attributes, attributes_req
+            )
+        return flow_processor.execute(content=content, attributes=attributes)
